@@ -7,11 +7,10 @@ import subprocess
 from naveen.logger import get_logger
 
 
-def stream_url(url: str, timeout: int = 3) -> None:
-    '''time out unit is seconds, not ms!'''
+def stream_url(url: str, timeout_in_seconds: int = 3) -> None:
 
     out = subprocess.run(["wget", url, "-q",
-                          "--timeout={}".format(str(timeout)),
+                          "--timeout={}".format(str(timeout_in_seconds)),
                           "-O", "-"],
                          capture_output=True)
     # returns std out as a unicode string, "return code is wget return code"
