@@ -4,7 +4,7 @@ from dataclasses import dataclass
 from typing import List
 
 
-@dataclass
+@dataclass(kw_only=True)
 class AbstractConfig(ABC):
     name: str
     reshaper: List[str]
